@@ -35,6 +35,7 @@ pub mod inbound {
 pub mod outbound {
     pub const ALL_SUCCESSES: &str = "snarkos_outbound_all_successes_total";
     pub const ALL_FAILURES: &str = "snarkos_outbound_all_failures_total";
+    pub const ALL_CACHE_HITS: &str = "snarkos_outbound_all_cache_hits_total";
 }
 
 pub mod connections {
@@ -44,6 +45,7 @@ pub mod connections {
     pub const CONNECTING: &str = "snarkos_connections_connecting_total";
     pub const CONNECTED: &str = "snarkos_connections_connected_total";
     pub const DISCONNECTED: &str = "snarkos_connections_disconnected_total";
+    pub const DURATION: &str = "snarkos_connections_average_duration";
 }
 
 pub mod handshakes {
@@ -56,8 +58,12 @@ pub mod handshakes {
 }
 
 pub mod queues {
+    pub const CONSENSUS: &str = "snarkos_queues_consensus_total";
     pub const INBOUND: &str = "snarkos_queues_inbound_total";
     pub const OUTBOUND: &str = "snarkos_queues_outbound_total";
+    pub const PEER_EVENTS: &str = "snarkos_queues_peer_events_total";
+    pub const STORAGE: &str = "snarkos_queues_storage_total";
+    pub const SYNC_ITEMS: &str = "snarkos_queues_sync_items_total";
 }
 
 pub mod misc {
@@ -67,4 +73,12 @@ pub mod misc {
     pub const DUPLICATE_SYNC_BLOCKS: &str = "snarkos_misc_duplicate_sync_blocks_total";
     pub const ORPHAN_BLOCKS: &str = "snarkos_misc_orphan_blocks_total";
     pub const RPC_REQUESTS: &str = "snarkos_misc_rpc_requests_total";
+    pub const BLOCK_PROCESSING_TIME: &str = "snarkos_misc_block_processing_time";
+}
+
+pub mod internal_rtt {
+    pub const GETPEERS: &str = "snarkos_internal_rtt_getpeers";
+    pub const GETSYNC: &str = "snarkos_internal_rtt_getsync";
+    pub const GETBLOCKS: &str = "snarkos_internal_rtt_getblocks";
+    pub const GETMEMORYPOOL: &str = "snarkos_internal_rtt_getmemorypool";
 }
